/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                            **** MATEMTICAS ****
/*
/*                     Ciclo escolar evaluado: 2009 - 2010
/*______________________________________________________________________________
/*
/*
/*      PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE MATEMTICAS
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2010_Alum_Mat.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2010_Alum_Mat.txt
/*         as como el archivo Excale03_2010_Alum_Mat.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2010_Alum_Mat.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2010_Alum_Mat.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 18 DE MAYO DEL 2012
/*
/*  ****************************************************************************/

/*****************************************************************************
/*    ACTUALIZACIN AL 26 DE NOVIEMBRE DEL 2013
/*
/*   - SE CORRIGIERON LAS ETIQUETAS DE LOS VALORES DE LA VARIABLE EDADC.
/*   - SE CORRIGIERON LAS ETIQUETAS DE LOS VALORES DE LA VARIABLE EDAD_AC.
/*
/*******************************************************************************/



LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2010_Alum_Mat.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "UP"      = "Urbano Pblico"
                       "RP"      = "Rural Pblico"
                       "EI"      = "Educacin Indgena"
                       "CC"      = "Cursos Comunitarios"
                       "UPV"     = "Privados"
                       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edadF       99        = "Respuesta omitida";
     VALUE edadcF      1         = "Ocho aos o menos"
                       2         = "Nueve aos"
                       3         = "Diez aos"
                       4         = "Once aos o ms"
                       9         = "Respuesta omitida";
     VALUE edadnF      1         = "Edad normativa"
                       2         = "Extra-edad"
                       9         = "Respuesta omitida";
     VALUE edad_acF    7         = "7 aos"
                       8         = "8 aos"
                       9         = "9 aos"
                       10        = "10 aos"
                       11        = "11 aos"
                       12        = "12 aos"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE mes_nacF    1         = "Enero"
                       2         = "Febrero"
                       3         = "Marzo"
                       4         = "Abril"
                       5         = "Mayo"
                       6         = "Junio"
                       7         = "Julio"
                       8         = "Agosto"
                       9         = "Septiembre"
                       10        = "Octubre"
                       11        = "Noviembre"
                       12        = "Diciembre"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE docenteF    99999     = "Respuesta omitida";
     VALUE ma1_h13F    0         = "Fallo"
                       1         = "Acierto"
                       5         = "Reactivo no alcanzado (se considera como no administrado)"
                       6         = "Reactivo no administrado por error de impresin"
                       7         = "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale03_2010_Alum_Mat;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            $7
       ENTEST             $6
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       MES_NAC            3
       W_ALU              8
       DOCENTE            5
       PMA_01             3
       PMA_02             3
       PMA_03             3
       PMA_04             3
       PMA_05             3
       PMA_06             3
       PMA_07             3
       PMA_09             3
       PMA_10             3
       PMA_12             3
       PMA_14             3
       PMB_02             3
       PMB_03             3
       PMB_04             3
       PMB_05             3
       PMB_06             3
       PMB_07             3
       PMB_08             3
       PMB_09             3
       PMB_10             3
       PMB_11             3
       PMB_12             3
       PMB_13             3
       PMC_01             3
       PMC_02             3
       PMC_03             3
       PMC_04             3
       PMC_05             3
       PMC_06             3
       PMC_07             3
       PMC_08             3
       PMC_09             3
       PMC_10             3
       PMC_11             3
       PMC_12             3
       PMC_13             3
       PMD_01             3
       PMD_02             3
       PMD_03             3
       PMD_04             3
       PMD_05             3
       PMD_06             3
       PMD_07             3
       PMD_08             3
       PMD_09             3
       PMD_10             3
       PMD_11             3
       PMD_12             3
       PMD_13             3
       PMD_14             3
       PME_01             3
       PME_02             3
       PME_03             3
       PME_04             3
       PME_05             3
       PME_07             3
       PME_08             3
       PME_09             3
       PME_10             3
       PME_11             3
       PME_12             3
       PME_13             3
       PMF_01             3
       PMF_02             3
       PMF_03             3
       PMF_04             3
       PMF_05             3
       PMF_06             3
       PMF_07             3
       PMF_08             3
       PMF_09             3
       PMF_10             3
       PMF_11             3
       PMF_12             3
       PMF_13             3
       PMG_02             3
       PMG_03             3
       PMG_04             3
       PMG_05             3
       PMG_06             3
       PMG_07             3
       PMG_08             3
       PMG_09             3
       PMG_10             3
       PMG_11             3
       PMG_12             3
       PMG_13             3
       PMH_01             3
       PMH_02             3
       PMH_03             3
       PMH_04             3
       PMH_05             3
       PMH_06             3
       PMH_07             3
       PMH_11             3
       PMH_12             3
       PMH_13             3
       PV1MAT             8
       PV2MAT             8
       PV3MAT             8
       PV4MAT             8
       PV5MAT             8
       MATNVL1            3
       MATNVL2            3
       MATNVL3            3
       MATNVL4            3
       MATNVL5            3
       MATNVBL1           3
       MATNVBL2           3
       MATNVBL3           3
       MATNVBL4           3
       MATNVBL5           3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
 ;

INFILE alum MISSOVER LINESIZE = 1130;
   INPUT
      NACIONAL           1 - 1
      ESCUELA            2 - 5
      ID_ENT             6 - 7
      NOM_ENT            8 - 26
      ID_MOD            27 - 27
      MOD               28 - 31
      ESTRATO           32 - 38
      ENTEST            39 - 44
      ALUMNO            45 - 50
      ID_INSTR          51 - 66
      SEXO              67 - 67
      EDAD              68 - 78
      EDADC             79 - 79
      EDADN             80 - 80
      EDAD_AC           81 - 82
      MES_NAC           83 - 84
      W_ALU             85 - 95
      DOCENTE           96 - 100
      PMA_01           101 - 101
      PMA_02           102 - 102
      PMA_03           103 - 103
      PMA_04           104 - 104
      PMA_05           105 - 105
      PMA_06           106 - 106
      PMA_07           107 - 107
      PMA_09           108 - 108
      PMA_10           109 - 109
      PMA_12           110 - 110
      PMA_14           111 - 111
      PMB_02           112 - 112
      PMB_03           113 - 113
      PMB_04           114 - 114
      PMB_05           115 - 115
      PMB_06           116 - 116
      PMB_07           117 - 117
      PMB_08           118 - 118
      PMB_09           119 - 119
      PMB_10           120 - 120
      PMB_11           121 - 121
      PMB_12           122 - 122
      PMB_13           123 - 123
      PMC_01           124 - 124
      PMC_02           125 - 125
      PMC_03           126 - 126
      PMC_04           127 - 127
      PMC_05           128 - 128
      PMC_06           129 - 129
      PMC_07           130 - 130
      PMC_08           131 - 131
      PMC_09           132 - 132
      PMC_10           133 - 133
      PMC_11           134 - 134
      PMC_12           135 - 135
      PMC_13           136 - 136
      PMD_01           137 - 137
      PMD_02           138 - 138
      PMD_03           139 - 139
      PMD_04           140 - 140
      PMD_05           141 - 141
      PMD_06           142 - 142
      PMD_07           143 - 143
      PMD_08           144 - 144
      PMD_09           145 - 145
      PMD_10           146 - 146
      PMD_11           147 - 147
      PMD_12           148 - 148
      PMD_13           149 - 149
      PMD_14           150 - 150
      PME_01           151 - 151
      PME_02           152 - 152
      PME_03           153 - 153
      PME_04           154 - 154
      PME_05           155 - 155
      PME_07           156 - 156
      PME_08           157 - 157
      PME_09           158 - 158
      PME_10           159 - 159
      PME_11           160 - 160
      PME_12           161 - 161
      PME_13           162 - 162
      PMF_01           163 - 163
      PMF_02           164 - 164
      PMF_03           165 - 165
      PMF_04           166 - 166
      PMF_05           167 - 167
      PMF_06           168 - 168
      PMF_07           169 - 169
      PMF_08           170 - 170
      PMF_09           171 - 171
      PMF_10           172 - 172
      PMF_11           173 - 173
      PMF_12           174 - 174
      PMF_13           175 - 175
      PMG_02           176 - 176
      PMG_03           177 - 177
      PMG_04           178 - 178
      PMG_05           179 - 179
      PMG_06           180 - 180
      PMG_07           181 - 181
      PMG_08           182 - 182
      PMG_09           183 - 183
      PMG_10           184 - 184
      PMG_11           185 - 185
      PMG_12           186 - 186
      PMG_13           187 - 187
      PMH_01           188 - 188
      PMH_02           189 - 189
      PMH_03           190 - 190
      PMH_04           191 - 191
      PMH_05           192 - 192
      PMH_06           193 - 193
      PMH_07           194 - 194
      PMH_11           195 - 195
      PMH_12           196 - 196
      PMH_13           197 - 197
      PV1MAT           198 - 205
      PV2MAT           206 - 213
      PV3MAT           214 - 221
      PV4MAT           222 - 229
      PV5MAT           230 - 237
      MATNVL1          238 - 238
      MATNVL2          239 - 239
      MATNVL3          240 - 240
      MATNVL4          241 - 241
      MATNVL5          242 - 242
      MATNVBL1         243 - 243
      MATNVBL2         244 - 244
      MATNVBL3         245 - 245
      MATNVBL4         246 - 246
      MATNVBL5         247 - 247
      WVARSTRR         248 - 250
      W_FSTR1          251 - 261
      W_FSTR2          262 - 272
      W_FSTR3          273 - 283
      W_FSTR4          284 - 294
      W_FSTR5          295 - 305
      W_FSTR6          306 - 316
      W_FSTR7          317 - 327
      W_FSTR8          328 - 338
      W_FSTR9          339 - 349
      W_FSTR10         350 - 360
      W_FSTR11         361 - 371
      W_FSTR12         372 - 382
      W_FSTR13         383 - 393
      W_FSTR14         394 - 404
      W_FSTR15         405 - 415
      W_FSTR16         416 - 426
      W_FSTR17         427 - 437
      W_FSTR18         438 - 448
      W_FSTR19         449 - 459
      W_FSTR20         460 - 470
      W_FSTR21         471 - 481
      W_FSTR22         482 - 492
      W_FSTR23         493 - 503
      W_FSTR24         504 - 514
      W_FSTR25         515 - 525
      W_FSTR26         526 - 536
      W_FSTR27         537 - 547
      W_FSTR28         548 - 558
      W_FSTR29         559 - 569
      W_FSTR30         570 - 580
      W_FSTR31         581 - 591
      W_FSTR32         592 - 602
      W_FSTR33         603 - 613
      W_FSTR34         614 - 624
      W_FSTR35         625 - 635
      W_FSTR36         636 - 646
      W_FSTR37         647 - 657
      W_FSTR38         658 - 668
      W_FSTR39         669 - 679
      W_FSTR40         680 - 690
      W_FSTR41         691 - 701
      W_FSTR42         702 - 712
      W_FSTR43         713 - 723
      W_FSTR44         724 - 734
      W_FSTR45         735 - 745
      W_FSTR46         746 - 756
      W_FSTR47         757 - 767
      W_FSTR48         768 - 778
      W_FSTR49         779 - 789
      W_FSTR50         790 - 800
      W_FSTR51         801 - 811
      W_FSTR52         812 - 822
      W_FSTR53         823 - 833
      W_FSTR54         834 - 844
      W_FSTR55         845 - 855
      W_FSTR56         856 - 866
      W_FSTR57         867 - 877
      W_FSTR58         878 - 888
      W_FSTR59         889 - 899
      W_FSTR60         900 - 910
      W_FSTR61         911 - 921
      W_FSTR62         922 - 932
      W_FSTR63         933 - 943
      W_FSTR64         944 - 954
      W_FSTR65         955 - 965
      W_FSTR66         966 - 976
      W_FSTR67         977 - 987
      W_FSTR68         988 - 998
      W_FSTR69         999 - 1009
      W_FSTR70        1010 - 1020
      W_FSTR71        1021 - 1031
      W_FSTR72        1032 - 1042
      W_FSTR73        1043 - 1053
      W_FSTR74        1054 - 1064
      W_FSTR75        1065 - 1075
      W_FSTR76        1076 - 1086
      W_FSTR77        1087 - 1097
      W_FSTR78        1098 - 1108
      W_FSTR79        1109 - 1119
      W_FSTR80        1120 - 1130
;





 LABEL
      NACIONAL    = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA     = "Identificador de la escuela"
      ID_ENT      = "Entidad federativa (identificador numrico)"
      NOM_ENT     = "Entidad federativa"
      ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD         = "Estrato escolar o Modalidad educativa"
      ESTRATO     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO      = "Identificador del alumno"
      ID_INSTR    = "Identificador del cuadernillo de examen"
      SEXO        = "Sexo del alumno"
      EDAD        = "Edad del alumno al mes de mayo de 2010, en aos (al momento de la aplicacin)"
      EDADC       = "Edad del alumno al mes de mayo de 2010, codificada (al momento de la aplicacin)"
      EDADN       = "Edad normativa"
      EDAD_AC     = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
      W_ALU       = "Peso muestral o ponderador del alumno"
      DOCENTE     = "Identificador del docente que imparte clases al alumno"
      PMA_01      = "Reactivo 47. Resolver problemas aditivos de cambio, con la incgnita en el estado inicial"
      PMA_02      = "Reactivo 6. Resolver problemas aditivos de cambio, con la incgnita en el estado final"
      PMA_03      = "Reactivo 75. Resolver problemas aditivos de comparacin, con la incgnita en la cantidad menor"
      PMA_04      = "Reactivo 71. Resolver un problema aditivo de cambio, con la incgnita en el estado final, con dos transformaciones"
      PMA_05      = "Reactivo 44. Calcular multiplicaciones sin transformacin donde un factor es de tres cifras y el otro de una"
      PMA_06      = "Reactivo 1. Calcular sumas con tres sumandos y sin transformacin"
      PMA_07      = "Reactivo 5. Leer el reloj de manecillas empleando cuartos y medias horas"
      PMA_09      = "Reactivo 53. Resolver problemas con nmeros fraccionarios que impliquen el uso de estructuras aditivas equivalentes"
      PMA_10      = "Reactivo 70. Resolver problemas que impliquen el uso del reloj de manecillas"
      PMA_12      = "Reactivo 46. Identificar trayectos en un croquis empleando los puntos cardinales"
      PMA_14      = "Reactivo 38. Identificar lo que se puede o no contestar a partir de la informacin dada en una imagen"
      PMB_02      = "Reactivo 16. Escribir con cifras un nmero de cuatro cifras sin cero intermedio"
      PMB_03      = "Reactivo 8. Calcular restas con nmeros de tres cifras en el minuendo y sustraendo sin transformacin"
      PMB_04      = "Reactivo 37. Identificar la operacin que resuelve un problema de reparto"
      PMB_05      = "Reactivo 55. Resolver problemas tasativos, sin apoyo grfico y cuya solucin implique el uso de la divisin"
      PMB_06      = "Reactivo 24. Resolver problemas que impliquen el uso de fracciones en su relacin parte-todo utilizando modelos discretos"
      PMB_07      = "Reactivo 81. Calcular restas con nmeros de tres cifras en el minuendo, dos en el sustraendo y con transformacin"
      PMB_08      = "Reactivo 68. Resolver problemas de reparto, sin apoyo grfico y cuya solucin implique el uso de la divisin"
      PMB_09      = "Reactivo 62. Identificar entre diferentes objetos el que pesa un kilogramo"
      PMB_10      = "Reactivo 48. Estimar la longitud de un centmetro"
      PMB_11      = "Reactivo 91. Identificar lados paralelos en una figura geomtrica"
      PMB_12      = "Reactivo 14. Leer e interpretar informacin organizada en tablas de doble entrada"
      PMB_13      = "Reactivo 21. Identificar el tamao aparente de objetos a partir de la perspectiva de la que se observan"
      PMC_01      = "Reactivo 2. Identificar la escritura con letra de un nmero de cuatro cifras"
      PMC_02      = "Reactivo 9. Identificar el sucesor de un nmero de tres cifras"
      PMC_03      = "Reactivo 94. Generalizar e identificar constantes aditivas de una cifra en secuencias numricas decrecientes"
      PMC_04      = "Reactivo 32. Identificar descomposiciones aditivas no convencionales de un nmero de cuatro cifras"
      PMC_05      = "Reactivo 49. Resolver problemas aditivos de comparacin, con la incgnita en la cantidad mayor"
      PMC_06      = "Reactivo 89. Resolver problemas aditivos de combinacin con la incgnita en una de las partes"
      PMC_07      = "Reactivo 93. Identificar fracciones a partir de su representacin grfica empleando modelos continuos"
      PMC_08      = "Reactivo 96. Calcular el rea de una figura no convencional a partir de una retcula incompleta"
      PMC_09      = "Reactivo 25. Resolver problemas de reparto utilizando modelos continuos"
      PMC_10      = "Reactivo 61. Resolver problemas que impliquen conocer la secuencia de los meses"
      PMC_11      = "Reactivo 19. Identificar rectngulos de dimensiones diversas en combinaciones y configuraciones geomtricas"
      PMC_12      = "Reactivo 41. Leer e interpretar pictogramas con dibujos que representan diferentes valores"
      PMC_13      = "Reactivo 86. Reconocer el nmero de caras de algunos prismas"
      PMD_01      = "Reactivo 45. Resolver problemas que implican una multiplicacin con arreglo rectangular"
      PMD_02      = "Reactivo 7. Identificar la escritura en cifras de un nmero cuatro dgitos"
      PMD_03      = "Reactivo 52. Identificar la operacin que resuelve un problema aditivo de comparacin"
      PMD_04      = "Reactivo 58. Resolver problemas de variacin proporcional conocido el valor unitario y cuya solucin implique una multiplicacin"
      PMD_05      = "Reactivo 63. Estimar la longitud de un metro"
      PMD_06      = "Reactivo 72. Identificar la operacin que resuelve un problema dado"
      PMD_07      = "Reactivo 59. Resolver problemas de reparto, con apoyo grfico y que puedan ser resueltos mediante una divisin"
      PMD_08      = "Reactivo 12. Resolver problemas con fracciones en su relacin parte-todo, con repartos mayores a la unidad y con modelos discretos"
      PMD_09      = "Reactivo 97. Identificar fracciones equivalentes"
      PMD_10      = "Reactivo 76. Medir la longitud de objetos utilizando unidades de medida no convencionales"
      PMD_11      = "Reactivo 83. Interpretar un croquis a partir de la informacin dada"
      PMD_12      = "Reactivo 15. Identificar una figuras a partir de la medida de sus lados"
      PMD_13      = "Reactivo 74. Identificar figuras geomtricas a partir de un eje de simetra"
      PMD_14      = "Reactivo 34. Leer e interpretar grficas de barras sencillas"
      PME_01      = "Reactivo 60. Identificar el valor posicional de un trmino en un nmero de cuatro cifras"
      PME_02      = "Reactivo 39. Identificar la operacin que resuelve un problema aditivo de combinacin, con la incgnita en el conjunto total"
      PME_03      = "Reactivo 33. Escribir y ordenar nmeros dadas sus tres cifras"
      PME_04      = "Reactivo 54. Calcular multiplicaciones con dos factores: uno de dos, el otro de una cifra y con transformacin"
      PME_05      = "Reactivo 78. Calcular multiplicaciones con dos factores; uno de tres, el otro de una cifra y con transformacin"
      PME_07      = "Reactivo 87. Calcular multiplicaciones con dos factores, ambos de dos cifras y con transformacin"
      PME_08      = "Reactivo 17. Imaginar la forma de las caras de algunos prismas"
      PME_09      = "Reactivo 50. Identificar el problema que puede ser resuelto con una operacin utilizando nmeros de tres cifras"
      PME_10      = "Reactivo 22. Comparar reas de figuras de diferente forma empleando la retcula"
      PME_11      = "Reactivo 35. Comparar superficies de manera perceptual"
      PME_12      = "Reactivo 82. Identificar la cantidad de ejes de simetra en una figura geomtrica"
      PME_13      = "Reactivo 13. Leer pictogramas sencillos"
      PMF_01      = "Reactivo 40. Identificar la escritura en cifras de un nmero de cuatro dgitos con cero intermedio"
      PMF_02      = "Reactivo 31. Identificar el antecesor de un nmero de cuatro cifras"
      PMF_03      = "Reactivo 51. identificar la operacin que resuelve un problema aditivo de combinacin, con la incgnita en una de las partes"
      PMF_04      = "Reactivo 67. Ordenar nmeros de cuatro cifras"
      PMF_05      = "Reactivo 30. Calcular una suma con dos sumados uno de tres cifras y el otro de dos presentada horizontalmente, sin transformacin"
      PMF_06      = "Reactivo 57. Identificar la operacin que resuelve un problema aditivo de cambio, que se resuelve con una suma"
      PMF_07      = "Reactivo 29. Resolver problemas que impliquen agregar una cantidad a otra, con la incgnita en esta ltima."
      PMF_08      = "Reactivo 92. Comparar dos fracciones con igual numerador"
      PMF_09      = "Reactivo 90. Resolver problemas que impliquen comparar el peso de objetos utilizando unidades de referencia convencionales"
      PMF_10      = "Reactivo 95. Ubicar espacialmente objetos, cuando el elemento de referencia no es el observador"
      PMF_11      = "Reactivo 11. Comparar la longitud de distintos objetos utilizando unidades de medida no convencionales"
      PMF_12      = "Reactivo 88. Identificar la forma de un objeto desde donde se le observa"
      PMF_13      = "Reactivo 85. Resolver problemas que impliquen comparar el peso de objetos utilizando el medio kilo"
      PMG_02      = "Reactivo 43. Identificar la escritura de un nmero de cuatro cifras en notacin desarrollada"
      PMG_03      = "Reactivo 36. Comparar entre s dos nmeros de cuatro cifras"
      PMG_04      = "Reactivo 65. Calcular una divisin con divisor de una cifra y dividendo de dos"
      PMG_05      = "Reactivo 77. Comparar dos fracciones con igual denominador"
      PMG_06      = "Reactivo 79. Resolver problemas aditivos sencillos cuya solucin implique hacer dos operaciones"
      PMG_07      = "Reactivo 84. Identificar el problema que puede ser resuelto dada una operacin con nmeros de dos cifras"
      PMG_08      = "Reactivo 27. Calcular sumas con nmeros de tres cifras, con tres sumandos y con transformacin"
      PMG_09      = "Reactivo 26. Medir objetos utilizando la regla graduada y el centmetro como unidad de medida"
      PMG_10      = "Reactivo 4. Comparar superficies utilizando como intermediario una retcula"
      PMG_11      = "Reactivo 10. Identificar figuras bsicas en combinaciones y configuraciones geomtricas"
      PMG_12      = "Reactivo 69. Ubicar espacialmente objetos, cuando el elemento de referencia coincide con la lateralidad del alumno"
      PMG_13      = "Reactivo 56. Resolver problemas que impliquen realizar operaciones con unidades de tiempo (horas y minutos)"
      PMH_01      = "Reactivo 3. Identificar el valor de un trmino en secuencias numricas crecientes con la constante aditiva de dos cifras"
      PMH_02      = "Reactivo 66. Resolver problemas aditivos de cambio, con la incgnita en el estado intermedio"
      PMH_03      = "Reactivo 64. Resolver problemas aditivos que implican comparar dos cantidades con la incgnita en la diferencia"
      PMH_04      = "Reactivo 28. Resolver problemas de variacin proporcional conocido el valor unitario y cuya solucin implique una multiplicacin o una suma iterada"
      PMH_05      = "Reactivo 42. Calcular restas de tres cifras en el minuendo, dos en el sustraendo y sin transformacin"
      PMH_06      = "Reactivo 18. Resolver problemas tasativos, con apoyo grfico y que puedan ser resueltos mediante una divisin"
      PMH_07      = "Reactivo 20. Resolver problemas aditivos de cambio, con la incgnita en el estado inicial y con apoyo grfico"
      PMH_11      = "Reactivo 73. Identificar lo que se puede o no contestar a partir de la informacin dada en una grfica de barras"
      PMH_12      = "Reactivo 80. Identificar la simetra en una figura"
      PMH_13      = "Reactivo 23. Identificar figuras geomtricas con relacin a la forma de sus lados"
      PV1MAT      = "Primer valor plausible de Matemticas"
      PV2MAT      = "Segundo valor plausible de Matemticas"
      PV3MAT      = "Tercer valor plausible de Matemticas"
      PV4MAT      = "Cuarto valor plausible de Matemticas"
      PV5MAT      = "Quinto valor plausible de Matemticas"
      MATNVL1     = "Nivel de logro en Matemticas. Asociado a PV1MAT. (Cuatro niveles)"
      MATNVL2     = "Nivel de logro en Matemticas. Asociado a PV2MAT. (Cuatro niveles)"
      MATNVL3     = "Nivel de logro en Matemticas. Asociado a PV3MAT. (Cuatro niveles)"
      MATNVL4     = "Nivel de logro en Matemticas. Asociado a PV4MAT. (Cuatro niveles)"
      MATNVL5     = "Nivel de logro en Matemticas. Asociado a PV5MAT. (Cuatro niveles)"
      MATNVBL1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV1MAT."
      MATNVBL2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV2MAT."
      MATNVBL3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV3MAT."
      MATNVBL4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV4MAT."
      MATNVBL5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Matemticas. Asociado a PV5MAT."
      WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;



 FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       ESTRATO            $char7.
       ENTEST             $char6.
       ALUMNO             5.
       ID_INSTR           $char16.
       SEXO               sexoF.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       MES_NAC            mes_nacF.
       DOCENTE            docenteF.
       PMA_01             ma1_h13F.
       PMA_02             ma1_h13F.
       PMA_03             ma1_h13F.
       PMA_04             ma1_h13F.
       PMA_05             ma1_h13F.
       PMA_06             ma1_h13F.
       PMA_07             ma1_h13F.
       PMA_09             ma1_h13F.
       PMA_10             ma1_h13F.
       PMA_12             ma1_h13F.
       PMA_14             ma1_h13F.
       PMB_02             ma1_h13F.
       PMB_03             ma1_h13F.
       PMB_04             ma1_h13F.
       PMB_05             ma1_h13F.
       PMB_06             ma1_h13F.
       PMB_07             ma1_h13F.
       PMB_08             ma1_h13F.
       PMB_09             ma1_h13F.
       PMB_10             ma1_h13F.
       PMB_11             ma1_h13F.
       PMB_12             ma1_h13F.
       PMB_13             ma1_h13F.
       PMC_01             ma1_h13F.
       PMC_02             ma1_h13F.
       PMC_03             ma1_h13F.
       PMC_04             ma1_h13F.
       PMC_05             ma1_h13F.
       PMC_06             ma1_h13F.
       PMC_07             ma1_h13F.
       PMC_08             ma1_h13F.
       PMC_09             ma1_h13F.
       PMC_10             ma1_h13F.
       PMC_11             ma1_h13F.
       PMC_12             ma1_h13F.
       PMC_13             ma1_h13F.
       PMD_01             ma1_h13F.
       PMD_02             ma1_h13F.
       PMD_03             ma1_h13F.
       PMD_04             ma1_h13F.
       PMD_05             ma1_h13F.
       PMD_06             ma1_h13F.
       PMD_07             ma1_h13F.
       PMD_08             ma1_h13F.
       PMD_09             ma1_h13F.
       PMD_10             ma1_h13F.
       PMD_11             ma1_h13F.
       PMD_12             ma1_h13F.
       PMD_13             ma1_h13F.
       PMD_14             ma1_h13F.
       PME_01             ma1_h13F.
       PME_02             ma1_h13F.
       PME_03             ma1_h13F.
       PME_04             ma1_h13F.
       PME_05             ma1_h13F.
       PME_07             ma1_h13F.
       PME_08             ma1_h13F.
       PME_09             ma1_h13F.
       PME_10             ma1_h13F.
       PME_11             ma1_h13F.
       PME_12             ma1_h13F.
       PME_13             ma1_h13F.
       PMF_01             ma1_h13F.
       PMF_02             ma1_h13F.
       PMF_03             ma1_h13F.
       PMF_04             ma1_h13F.
       PMF_05             ma1_h13F.
       PMF_06             ma1_h13F.
       PMF_07             ma1_h13F.
       PMF_08             ma1_h13F.
       PMF_09             ma1_h13F.
       PMF_10             ma1_h13F.
       PMF_11             ma1_h13F.
       PMF_12             ma1_h13F.
       PMF_13             ma1_h13F.
       PMG_02             ma1_h13F.
       PMG_03             ma1_h13F.
       PMG_04             ma1_h13F.
       PMG_05             ma1_h13F.
       PMG_06             ma1_h13F.
       PMG_07             ma1_h13F.
       PMG_08             ma1_h13F.
       PMG_09             ma1_h13F.
       PMG_10             ma1_h13F.
       PMG_11             ma1_h13F.
       PMG_12             ma1_h13F.
       PMG_13             ma1_h13F.
       PMH_01             ma1_h13F.
       PMH_02             ma1_h13F.
       PMH_03             ma1_h13F.
       PMH_04             ma1_h13F.
       PMH_05             ma1_h13F.
       PMH_06             ma1_h13F.
       PMH_07             ma1_h13F.
       PMH_11             ma1_h13F.
       PMH_12             ma1_h13F.
       PMH_13             ma1_h13F.
;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;


   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;


   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;


   IF  docente = 99999 THEN  docente = .S;


   ARRAY perdidos3(97)
                 PMA_01 PMA_02 PMA_03 PMA_04 PMA_05 PMA_06 PMA_07 PMA_09 PMA_10 PMA_12
                 PMA_14 PMB_02 PMB_03 PMB_04 PMB_05 PMB_06 PMB_07 PMB_08 PMB_09 PMB_10
                 PMB_11 PMB_12 PMB_13 PMC_01 PMC_02 PMC_03 PMC_04 PMC_05 PMC_06 PMC_07
                 PMC_08 PMC_09 PMC_10 PMC_11 PMC_12 PMC_13 PMD_01 PMD_02 PMD_03 PMD_04
                 PMD_05 PMD_06 PMD_07 PMD_08 PMD_09 PMD_10 PMD_11 PMD_12 PMD_13 PMD_14
                 PME_01 PME_02 PME_03 PME_04 PME_05 PME_07 PME_08 PME_09 PME_10 PME_11
                 PME_12 PME_13 PMF_01 PMF_02 PMF_03 PMF_04 PMF_05 PMF_06 PMF_07 PMF_08
                 PMF_09 PMF_10 PMF_11 PMF_12 PMF_13 PMG_02 PMG_03 PMG_04 PMG_05 PMG_06
                 PMG_07 PMG_08 PMG_09 PMG_10 PMG_11 PMG_12 PMG_13 PMH_01 PMH_02 PMH_03
                 PMH_04 PMH_05 PMH_06 PMH_07 PMH_11 PMH_12 PMH_13;
   DO  i=1 TO 97;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
